Stan Math Library: stan/math/rev/scal/fun/abs.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

abs.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_ABS_HPP
2 #define STAN_MATH_REV_SCAL_FUN_ABS_HPP
3
4 #include <stan/math/rev/scal/fun/fabs.hpp>
5
6 namespace stan {
7 namespace math {
8
35 inline var abs(const var& a) {
36 return fabs(a);
37 }
38
39 }
40 }
41 #endif
stan::math::abs
fvar< T > abs(const fvar< T > &x)
Definition: abs.hpp:15
stan::math::fabs
fvar< T > fabs(const fvar< T > &x)
Definition: fabs.hpp:14
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
fabs.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.